@@ -9,8 +9,8 @@ from typing import Union, Optional, Dict, List
 __all__ = [
     'ValidationError',
     'RequiredValueError',
+    'FieldNotAllowedError',
     'InvalidTypeError',
-    'InternalValidationError',
 ]
 
 
@@ -78,6 +78,16 @@ class RequiredValueError(ValidationError):
     code = 'required_value'
 
 
+class FieldNotAllowedError(ValidationError):
+    """
+    Validation error raised by the `RejectValidator` for any input data (except for `None` if allowed by the validator).
+
+    In practice, this error mostly is raised when the user specifies an input value for a field in a validataclass that
+    uses a `RejectValidator` (e.g. because the user is not allowed to set this field).
+    """
+    code = 'field_not_allowed'
+
+
 class InvalidTypeError(ValidationError):
     """
     Validation error raised when the input data has the wrong data type.
@@ -120,24 +130,3 @@ class InvalidTypeError(ValidationError):
         else:
             base_dict.update({'expected_types': self.expected_types})
         return base_dict
-
-
-class InternalValidationError(ValidationError):
-    """
-    Validation error raised when an unhandled exception (that is not a `ValidationError` subclass) occurs, e.g. in post validation.
-
-    The unhandled exception can be wrapped inside the 'internal_error' argument, which will NOT be included in `to_dict()` but will
-    be accessible via `error.internal_error` or `repr(error)` for debugging purposes.
-    """
-    code = 'internal_error'
-    internal_error: Optional[Exception] = None
-
-    def __init__(self, *, internal_error: Optional[Exception] = None, **kwargs):
-        super().__init__(**kwargs)
-        self.internal_error = internal_error
-
-    def _get_repr_dict(self) -> Dict[str, str]:
-        base_dict = super()._get_repr_dict()
-        if self.internal_error is not None:
-            base_dict['internal_error'] = repr(self.internal_error)
-        return base_dict
