@@ -16,7 +16,7 @@ __all__ = [
 
 
 class RegexValidator(StringValidator):
-    """
+    r"""
     Validator that matches strings against a regular expression, optionally with minimal/maximal length requirements.
 
     This validator is based on the `StringValidator` which first handles type checking and optional length requirements.
@@ -34,6 +34,11 @@ class RegexValidator(StringValidator):
     using the parameters `custom_error_class` (which must be a subclass of `ValidationError`) and/or `custom_error_code`
     (which is a string that overrides the default error code).
 
+    By default, valid input strings are returned unmodified. Alternatively, you can specify an output template with the
+    `output_template` parameter which will then be expanded to generate the output string using
+    [`re.Match.expand`](https://docs.python.org/3/library/re.html#re.Match.expand), i.e. backreferences to regex groups
+    will be replaced with the groups' contents.
+
     By default only "safe" singleline strings are allowed (i.e. no non-printable characters). See the `StringValidator`
     options `unsafe` and `multiline` for more details.
 
@@ -55,6 +60,10 @@ class RegexValidator(StringValidator):
     # As above, but setting string length requirements to only allow 6-digit hex numbers (e.g. '123abc')
     RegexValidator(re.compile(r'[0-9a-f]+', re.IGNORECASE), min_length=6, max_length=6)
 
+    # Output a template substituted with match groups instead of original input string (e.g. '123abc' -> '0x123abc')
+    RegexValidator(re.compile(r'(?:0[xh])?([0-9a-f]+)', re.IGNORECASE), r'0x\1')
+    RegexValidator(re.compile(r'(?:0[xh])?(?P<hex>[0-9a-f]+)', re.IGNORECASE), r'0x\g<hex>')  # same with named groups
+
     # Set a custom error code (will raise RegexMatchError with error code 'invalid_hex_number' on error)
     RegexValidator(re.compile(r'[0-9a-f]+'), custom_error_code='invalid_hex_number')
 
@@ -72,6 +81,9 @@ class RegexValidator(StringValidator):
     # Precompiled regex pattern
     regex_pattern: re.Pattern
 
+    # Output template
+    output_template: Optional[str]
+
     # Exception class to use when regex matching fails
     custom_error_class: Type[ValidationError]
 
@@ -81,6 +93,7 @@ class RegexValidator(StringValidator):
     def __init__(
         self,
         pattern: Union[re.Pattern, str],
+        output_template: Optional[str] = None,
         *,
         custom_error_class: Type[ValidationError] = RegexMatchError,
         custom_error_code: Optional[str] = None,
@@ -94,6 +107,7 @@ class RegexValidator(StringValidator):
 
         Parameters:
             pattern: `re.Pattern` or `str`, regex pattern to use for validation (required)
+            output_template: Optional `str`, template to be used in output, will be supplied to match.expand() (default: None)
             custom_error_class: Subclass of `ValidationError` raised when regex matching fails (default: RegexMatchError)
             custom_error_code: Optional `str`, overrides the default error code in the regex match exception (default: None)
         """
@@ -110,19 +124,31 @@ class RegexValidator(StringValidator):
         else:
             self.regex_pattern = re.compile(pattern)
 
+        # Save output_template
+        self.output_template = output_template
+
         # Save custom error class and code
         self.custom_error_class = custom_error_class
         self.custom_error_code = custom_error_code
 
     def validate(self, input_data: Any) -> str:
         """
-        Validate input as string and match full string against regular expression. Returns unmodified string.
+        Validate input as string and match full string against regular expression.
+
+        Returns unmodified string, unless when output template was supplied.
         """
         # Validate input with base StringValidator (checks length requirements)
-        input_data = super().validate(input_data)
+        output = super().validate(input_data)
 
         # Match full string against Regex pattern
-        if not self.regex_pattern.fullmatch(input_data):
+        match = self.regex_pattern.fullmatch(input_data)
+
+        # Raise error if match not found
+        if not match:
             raise self.custom_error_class(code=self.custom_error_code)
 
-        return input_data
+        # Expand template if output_template was supplied
+        if self.output_template is not None:
+            output = match.expand(self.output_template)
+
+        return output
